==> DAAG_0.84.tar.gz: DAAG/data/frostedflakes.R <==
"frostedflakes" <-
structure(list(Lab = c(36.3, 33.2, 39, 37.3, 40.7, 38.4, 35.8, 
36, 37.9, 42.6, 40, 43.5, 36.6, 33.7, 40.5, 38.7, 36.2, 41.6, 
37.8, 40.5, 38.9, 36, 41.1, 40, 35.5, 34.3, 33, 36.9, 36.3, 38.5, 
35.1, 38.7, 34, 42.3, 41.4, 38.2, 38.3, 37.4, 37.5, 36.5, 34.8, 
38.1, 41, 35.4, 35, 37.9, 39.1, 33.3, 40.4, 34.9, 33.5, 35.8, 
36.6, 38.3, 33.1, 37.4, 39.9, 38.4, 36.1, 33.6, 35.1, 37.4, 38.2, 
39, 31.6, 36.1, 36.6, 36.4, 39.9, 38.8, 39.1, 34.7, 37.3, 39.1, 
38.8, 38.7, 36.5, 37.3, 39.9, 34, 39.4, 36.4, 34.8, 41.1, 33.8, 
41.4, 39.1, 38.3, 37.7, 38.4, 40.9, 36.5, 40.5, 39.7, 40.6, 38.9, 
39.3, 37.1, 35.6, 36.8), HPLC = c(35.1, 35.9, 40.1, 35.5, 37.9, 
39.5, 38.5, 37.9, 41.2, 45.7, 38.3, 42.3, 39, 30.8, 37.3, 39.5, 
40.3, 42, 36.9, 41.2, 39.3, 35.6, 40.9, 37.6, 35.5, 35.5, 32.4, 
36.1, 36.1, 39, 38.5, 40, 35.4, 40.9, 39.4, 38.6, 39.6, 39.2, 
36.4, 36.1, 38.1, 39.6, 40.8, 37.4, 37.6, 36, 37.2, 33, 41.9, 
37.9, 38.1, 37.4, 40.1, 40.7, 35.4, 41.4, 40.2, 39.1, 34.7, 33.9, 
36.7, 36.3, 38.8, 43, 33.9, 35.6, 34.8, 35.8, 41.4, 39.2, 36.9, 
33.7, 36.1, 40.2, 39.9, 36.6, 35.8, 38.6, 37.5, 33.7, 39.9, 35.5, 
34.9, 40.7, 31.3, 39.5, 37.9, 38.7, 36.1, 42.8, 42.7, 40.9, 40, 
41.2, 41.5, 42, 42.6, 40.8, 40.2, 40.6)), .Names = c("Lab", "HPLC"
), row.names = c("1", "2", "3", "4", "5", "6", "7", "8", "9", 
"10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", 
"21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", 
"32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", 
"43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", 
"54", "55", "56", "57", "58", "59", "60", "61", "62", "63", "64", 
"65", "66", "67", "68", "69", "70", "71", "72", "73", "74", "75", 
"76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86", 
"87", "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", 
"98", "99", "100"), class = "data.frame")

==> DAAG_1.02.tar.gz: DAAG/data/frostedflakes.R <==
"frostedflakes" <-
structure(list(Lab = c(36.3, 33.2, 39, 37.3, 40.7, 38.4, 35.8, 
36, 37.9, 42.6, 40, 43.5, 36.6, 33.7, 40.5, 38.7, 36.2, 41.6, 
37.8, 40.5, 38.9, 36, 41.1, 40, 35.5, 34.3, 33, 36.9, 36.3, 38.5, 
35.1, 38.7, 34, 42.3, 41.4, 38.2, 38.3, 37.4, 37.5, 36.5, 34.8, 
38.1, 41, 35.4, 35, 37.9, 39.1, 33.3, 40.4, 34.9, 33.5, 35.8, 
36.6, 38.3, 33.1, 37.4, 39.9, 38.4, 36.1, 33.6, 35.1, 37.4, 38.2, 
39, 31.6, 36.1, 36.6, 36.4, 39.9, 38.8, 39.1, 34.7, 37.3, 39.1, 
38.8, 38.7, 36.5, 37.3, 39.9, 34, 39.4, 36.4, 34.8, 41.1, 33.8, 
41.4, 39.1, 38.3, 37.7, 38.4, 40.9, 36.5, 40.5, 39.7, 40.6, 38.9, 
39.3, 37.1, 35.6, 36.8), IA400 = c(35.1, 35.9, 40.1, 35.5, 37.9, 
39.5, 38.5, 37.9, 41.2, 45.7, 38.3, 42.3, 39, 30.8, 37.3, 39.5, 
40.3, 42, 36.9, 41.2, 39.3, 35.6, 40.9, 37.6, 35.5, 35.5, 32.4, 
36.1, 36.1, 39, 38.5, 40, 35.4, 40.9, 39.4, 38.6, 39.6, 39.2, 
36.4, 36.1, 38.1, 39.6, 40.8, 37.4, 37.6, 36, 37.2, 33, 41.9, 
37.9, 38.1, 37.4, 40.1, 40.7, 35.4, 41.4, 40.2, 39.1, 34.7, 33.9, 
36.7, 36.3, 38.8, 43, 33.9, 35.6, 34.8, 35.8, 41.4, 39.2, 36.9, 
33.7, 36.1, 40.2, 39.9, 36.6, 35.8, 38.6, 37.5, 33.7, 39.9, 35.5, 
34.9, 40.7, 31.3, 39.5, 37.9, 38.7, 36.1, 42.8, 42.7, 40.9, 40, 
41.2, 41.5, 42, 42.6, 40.8, 40.2, 40.6)), .Names = c("Lab", "IA400"
), row.names = c("1", "2", "3", "4", "5", "6", "7", "8", "9", 
"10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", 
"21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", 
"32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", 
"43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", 
"54", "55", "56", "57", "58", "59", "60", "61", "62", "63", "64", 
"65", "66", "67", "68", "69", "70", "71", "72", "73", "74", "75", 
"76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86", 
"87", "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", 
"98", "99", "100"), class = "data.frame")
